@@ -44,11 +44,11 @@ Test::MockFile - Allows tests to validate code that can interact with files with
 
 =head1 VERSION
 
-Version 0.026
+Version 0.027
 
 =cut
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 our %files_being_mocked;
 
@@ -70,13 +70,16 @@ Intercepts file system calls for specific files so unit testing can take place w
 
 This is useful for L<small tests|https://en.wikipedia.org/wiki/Google_Test#Small_Tests_(Unit_Tests)> where file interaction is discouraged.
 
-A strict mode is even provided which can throw a die when files are accessed during your tests!
+A strict mode is even provided (and turned on by default) which can throw a die when files are accessed during your tests!
 
     # Loaded before Test::MockFile so uses the core perl functions without any hooks.
     use Module::I::Dont::Want::To::Alter;
 
-    # strict mode
-    use Test::MockFile qw< strict >;
+    # strict mode by default
+    use Test::MockFile;
+
+    # non-strict mode
+    use Test::MockFile qw< nostrict >;
 
     # Be sure to assign the output of mocks, they disappear when they go out of scope
     my $mock_file = Test::MockFile->file("/foo/bar", "contents\ngo\nhere");
@@ -111,11 +114,12 @@ A strict mode is even provided which can throw a die when files are accessed dur
 
 =head1 IMPORT
 
-If the module is loaded in strict mode, any file checks, open, sysopen, opendir, stat, or lstat will throw a die.
+When the module is loaded with no parameters, strict mode is turned on. Any file checks,
+C<open>, C<sysopen>, C<opendir>, C<stat>, or C<lstat> will throw a die.
 
 For example:
 
-    use Test::MockFile qw< strict >;
+    use Test::MockFile;
 
     # This will not die.
     my $file    = Test::MockFile->file("/bar", "...");
@@ -130,6 +134,10 @@ For example:
     -e '/file';
     -l '/file';
 
+If we want to load the module without strict mode:
+
+    use Test::MockFile qw< nostrict >;
+
 Relative paths are not supported:
 
     use Test::MockFile;
@@ -139,11 +147,6 @@ Relative paths are not supported:
     $file = Test::MockFile->file( '/bar',        '...' ); # ok     - absolute path
     $file = Test::MockFile->file( 'bar', '...' );         # ok     - current dir
 
-And if you have multiple forward slashes, it will confess as well:
-
-    use Test::MockFile;
-    $file = Test::MockFile->file( '//bar', '...' );
-
 =cut
 
 our %authorized_strict_mode_packages;
@@ -237,9 +240,8 @@ sub _strict_mode_violation {
 sub import {
     my ( $class, @args ) = @_;
 
-    if ( grep { $_ =~ m/strict/i } @args ) {
-        add_file_access_hook( \&_strict_mode_violation );
-    }
+    grep { $_ eq 'nostrict' } @args
+        and clear_file_access_hooks();
 }
 
 =head1 SUBROUTINES/METHODS
@@ -384,11 +386,6 @@ sub symlink {
 sub _validate_path {
     my $path = shift;
 
-    # Multiple forward slashes
-    if ( $path =~ m[/{2,}] ) {
-        confess('Repeated forward slashes in path');
-    }
-
     # Reject the following:
     # ./ ../ /. /.. /./ /../
     if ( $path =~ m{ ( ^ | / ) \.{2} ( / | $ ) }xms ) {
@@ -708,6 +705,10 @@ sub _abs_path_to_file {
     my ($path) = shift;
 
     defined $path or return;
+
+    # cleanup multiple slashes
+    $path =~ s{//+}{/}xmsg;
+
     return $path if $path =~ m{^/};
 
     return Cwd::getcwd() . "/$path";
@@ -1134,7 +1135,7 @@ One use might be:
 
 =cut
 
-my @file_access_hooks;
+my @file_access_hooks = ( \&_strict_mode_violation );
 
 sub add_file_access_hook {
     my ($code_ref) = @_;
@@ -1656,7 +1657,11 @@ BEGIN {
 
         if ( !defined $file ) {
             warn 'Use of uninitialized value in readlink';
-            $! = ENOENT;
+            if ( $^O eq 'freebsd' ) {
+                $! = EINVAL;
+            } else {
+                $! = ENOENT;
+            }
             return;
         }
 
@@ -1891,7 +1896,35 @@ BEGIN {
     };
 }
 
-=head1 BAREWORD FILEHANDLE FAILURES
+=head1 CAEATS AND LIMITATIONS
+
+=head2 DEBUGGER UNDER STRICT MODE
+
+If you want to use the Perl debugger (L<perldebug>) on any code that uses
+L<Test::MockFile> in strict mode, you will need to load L<Term::ReadLine>
+beforehand, because it loads a file. Under the debugger, the debugger will
+load the module after L<Test::MockFile> and get mad.
+
+    # Load it from the command line
+    perl -MTerm::ReadLine -d code.pl
+
+    # Or alternatively, add this to the top of your code:
+    use Term::ReadLine
+
+=head2 FILENO IS UNSUPPORTED
+
+Filehandles can provide the file descriptor (in number) using the C<fileno>
+keyword but this is purposefully unsupported in L<Test::MockFile>.
+
+The reaosn is that by mocking a file, we're creating an alternative file
+system. Returning a C<fileno> (file descriptor number) would require creating
+file descriptor numbers that would possibly conflict with the file desciptors
+you receive from the real filesystem.
+
+In short, this is a recipe for buggy tests or worse - truly destructive
+behavior. If you have a need for a real file, we suggest L<File::Temp>.
+
+=head2 BAREWORD FILEHANDLE FAILURES
 
 There is a particular type of bareword filehandle failures that cannot be
 fixed.
